@@ -108,8 +108,7 @@ class AthenaClient:
         """Run a specified query"""
         try:
             payload = json.dumps(
-                {"user_name": self._user_name, "password": self._password, "query_string": query_string,
-                 "result_as_df": result_as_df})
+                {"user_name": self._user_name, "password": self._password, "query_string": query_string})
             r = requests.post(SERVICE_URL + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS)
             response = r.json()
             if result_as_df:
